summaryrefslogtreecommitdiffstatshomepage
path: root/src/mame
diff options
context:
space:
mode:
author Dirk Best <mail@dirk-best.de>2021-12-02 13:33:44 +0100
committer Dirk Best <mail@dirk-best.de>2021-12-02 13:34:15 +0100
commit620f531c541aecfa5bade33be802d053a10d03ac (patch)
tree00406dbb05651a7a954e706857d3cf550bd31ea9 /src/mame
parent9f45ed5ac482abd03ccb34f51c1ff25fcd360930 (diff)
Remove a few outdated references to MESS
Diffstat (limited to 'src/mame')
-rw-r--r--src/mame/audio/vboy.cpp2
-rw-r--r--src/mame/audio/vboy.h2
-rw-r--r--src/mame/drivers/a7800.cpp2
-rw-r--r--src/mame/drivers/apple2gs.cpp2
-rw-r--r--src/mame/drivers/at.cpp2
-rw-r--r--src/mame/drivers/atari400.cpp5
-rw-r--r--src/mame/drivers/atom.cpp2
-rw-r--r--src/mame/drivers/avigo.cpp4
-rw-r--r--src/mame/drivers/bartop52.cpp2
-rw-r--r--src/mame/drivers/bfcobra.cpp2
-rw-r--r--src/mame/drivers/camplynx.cpp2
-rw-r--r--src/mame/drivers/maxaflex.cpp2
-rw-r--r--src/mame/drivers/mbee.cpp4
-rw-r--r--src/mame/drivers/megadriv.cpp6
-rw-r--r--src/mame/drivers/mtouchxl.cpp2
-rw-r--r--src/mame/drivers/mz2500.cpp4
-rw-r--r--src/mame/drivers/nc.cpp8
-rw-r--r--src/mame/drivers/pc8801.cpp2
-rw-r--r--src/mame/drivers/pencil2.cpp2
-rw-r--r--src/mame/drivers/photon2.cpp2
-rw-r--r--src/mame/drivers/ps2.cpp2
-rw-r--r--src/mame/drivers/ql.cpp2
-rw-r--r--src/mame/drivers/spectrum.cpp2
-rw-r--r--src/mame/drivers/swtpc09.cpp2
-rw-r--r--src/mame/drivers/thomson.cpp8
-rw-r--r--src/mame/drivers/ti99_4p.cpp4
-rw-r--r--src/mame/drivers/ti99_8.cpp2
-rw-r--r--src/mame/drivers/v1050.cpp12
-rw-r--r--src/mame/drivers/zx.cpp2
-rw-r--r--src/mame/includes/n64.h2
-rw-r--r--src/mame/machine/amstrad.cpp6
-rw-r--r--src/mame/machine/bbc.cpp6
-rw-r--r--src/mame/machine/bebox.cpp4
-rw-r--r--src/mame/machine/cdicdic.cpp4
-rw-r--r--src/mame/machine/dccons.cpp2
-rw-r--r--src/mame/machine/electron.cpp5
-rw-r--r--src/mame/machine/n64.cpp2
-rw-r--r--src/mame/machine/thomson.cpp2
-rw-r--r--src/mame/video/bbc.cpp6
-rw-r--r--src/mame/video/electron.cpp4
-rw-r--r--src/mame/video/nick.cpp1
-rw-r--r--src/mame/video/tia.cpp2
42 files changed, 56 insertions, 85 deletions
diff --git a/src/mame/audio/vboy.cpp b/src/mame/audio/vboy.cpp
index 3d6abbe6b89..d7b3f587eed 100644
--- a/src/mame/audio/vboy.cpp
+++ b/src/mame/audio/vboy.cpp
@@ -4,7 +4,7 @@
vboy.c - Virtual Boy audio emulation
By Richard Bannister and Gil Pedersen.
- MESS device adaptation by R. Belmont
+ MAME device adaptation by R. Belmont
*/
#include "emu.h"
diff --git a/src/mame/audio/vboy.h b/src/mame/audio/vboy.h
index ca4de746db3..e6d1f36deee 100644
--- a/src/mame/audio/vboy.h
+++ b/src/mame/audio/vboy.h
@@ -4,7 +4,7 @@
vboy.h - Virtual Boy audio emulation
By Richard Bannister and Gil Pedersen.
- MESS device adaptation by R. Belmont
+ MAME device adaptation by R. Belmont
*/
#ifndef MAME_AUDIO_VBOY_H
#define MAME_AUDIO_VBOY_H
diff --git a/src/mame/drivers/a7800.cpp b/src/mame/drivers/a7800.cpp
index 580c7f8fc06..2800537f29c 100644
--- a/src/mame/drivers/a7800.cpp
+++ b/src/mame/drivers/a7800.cpp
@@ -445,7 +445,7 @@ some variation of proportions even within the same display type.
One side effect of this on the console's palette is that some values of
red may appear too pinkish - Too much blue to red. This is not the same
as a traditional tint-hue control adjustment; rather, can be demonstrated
-by changing the blue ratio values via MESS HLSL settings.
+by changing the blue ratio values via MAME HLSL settings.
Lastly, the Atari 2600 & 5200 NTSC color palettes hold the same hue
structure order and have similar appearance differences that are dependent
diff --git a/src/mame/drivers/apple2gs.cpp b/src/mame/drivers/apple2gs.cpp
index 968eff0c08f..2582d4cca89 100644
--- a/src/mame/drivers/apple2gs.cpp
+++ b/src/mame/drivers/apple2gs.cpp
@@ -1267,7 +1267,7 @@ void apple2gs_state::adb_write_datareg(u8 data)
}
// real rom 3 h/w reads 0x90 when idle, 0x98 when key pressed
-// current MESS reads back 0xb0 when idle
+// current MAME reads back 0xb0 when idle
u8 apple2gs_state::adb_read_kmstatus()
{
return m_adb_kmstatus;
diff --git a/src/mame/drivers/at.cpp b/src/mame/drivers/at.cpp
index 6d1a5122504..a89a1df1b27 100644
--- a/src/mame/drivers/at.cpp
+++ b/src/mame/drivers/at.cpp
@@ -437,7 +437,7 @@ void at_state::init_at_common(int xmsbase)
{
address_space& space = m_maincpu->space(AS_PROGRAM);
- /* MESS managed RAM */
+ /* managed RAM */
membank("bank10")->set_base(m_ram->pointer());
if (m_ram->size() > xmsbase)
diff --git a/src/mame/drivers/atari400.cpp b/src/mame/drivers/atari400.cpp
index 08ca8a2705f..70498a3c628 100644
--- a/src/mame/drivers/atari400.cpp
+++ b/src/mame/drivers/atari400.cpp
@@ -1,9 +1,8 @@
// license:GPL-2.0+
// copyright-holders:Juergen Buchmueller
/******************************************************************************
- Atari 400/800
- MESS Driver
+ Atari 400/800
Juergen Buchmueller, June 1998
@@ -1019,7 +1018,7 @@ One side effect of this on the console's palette is that some
values of red may appear too pinkish - Too much blue to red.
This is not the same as a traditional tint-hue control
adjustment; rather, can be demonstrated by changing the blue
-ratio values via MESS HLSL settings.
+ratio values via MAME HLSL settings.
Lastly, the Atari 2600 & 7800 NTSC color palettes hold the same
hue structure order and have similar appearance differences
diff --git a/src/mame/drivers/atom.cpp b/src/mame/drivers/atom.cpp
index d703f967a70..54f218b09b4 100644
--- a/src/mame/drivers/atom.cpp
+++ b/src/mame/drivers/atom.cpp
@@ -53,7 +53,7 @@ Hardware: PPIA 8255
thought this was a bad design and have modified their Atom's and dos rom
to use a different memory area.
- The atom driver in MESS uses the original memory area.
+ The atom driver in MAME uses the original memory area.
http://www.xs4all.nl/~fjkraan/comp/atom/index.html
diff --git a/src/mame/drivers/avigo.cpp b/src/mame/drivers/avigo.cpp
index a1b26ee0273..5fdbc433b27 100644
--- a/src/mame/drivers/avigo.cpp
+++ b/src/mame/drivers/avigo.cpp
@@ -2,8 +2,6 @@
// copyright-holders:Kevin Thacker,Sandro Ronco
/******************************************************************************
- avigo.c
-
TI "Avigo" PDA
@@ -64,8 +62,6 @@
from an existing emulation written by Hans Pufal. Hans's emulator
is also written from educated guesswork.
- MESS Driver by Kevin Thacker and Sandro Ronco
-
******************************************************************************/
diff --git a/src/mame/drivers/bartop52.cpp b/src/mame/drivers/bartop52.cpp
index 6cfff80a172..8205ebba815 100644
--- a/src/mame/drivers/bartop52.cpp
+++ b/src/mame/drivers/bartop52.cpp
@@ -4,7 +4,7 @@
Atari Bartop 5200 prototype system
Driver by Mariusz Wojcieszek
- Based on Atari 400/800 MESS Driver by Juergen Buchmueller
+ Based on Atari 400/800 MAME Driver by Juergen Buchmueller
Hardware was based on Atari 5200 game console with additional coin and timer hardware.
System was intented to run in barrooms and taverns. Software was based on Atari 5200
diff --git a/src/mame/drivers/bfcobra.cpp b/src/mame/drivers/bfcobra.cpp
index 647b2d68310..13617aedec8 100644
--- a/src/mame/drivers/bfcobra.cpp
+++ b/src/mame/drivers/bfcobra.cpp
@@ -1019,7 +1019,7 @@ void bfcobra_state::rombank_w(uint8_t data)
Split into machine\bfcobra.cpp !
- Alternatively chuck it all away and borrow the MESS implementation
+ Alternatively chuck it all away and use the existing implementation
because it's a million times better.
***************************************************************************/
diff --git a/src/mame/drivers/camplynx.cpp b/src/mame/drivers/camplynx.cpp
index 42552dbe3f7..5f0d8087061 100644
--- a/src/mame/drivers/camplynx.cpp
+++ b/src/mame/drivers/camplynx.cpp
@@ -704,7 +704,7 @@ void camplynx_state::port80_w(u8 data)
/* DAC port (6-bit). If writing cassette, output goes to tape as a sine wave, otherwise it goes to speaker.
There is code below to write as a sine wave or a square wave, both work and can be loaded successfully.
However the PALE emulator cannot load either of them, although it loads its own output.
- MESS can load PALE's wav files though.
+ MAME can load PALE's wav files though.
Currently square wave output is selected. */
void camplynx_state::port84_w(u8 data)
diff --git a/src/mame/drivers/maxaflex.cpp b/src/mame/drivers/maxaflex.cpp
index a6730dd10b3..b06517e12f3 100644
--- a/src/mame/drivers/maxaflex.cpp
+++ b/src/mame/drivers/maxaflex.cpp
@@ -5,7 +5,7 @@
by Mariusz Wojcieszek
- Based on Atari 400/800 MESS Driver by Juergen Buchmueller
+ Based on Atari 400/800 MAME Driver by Juergen Buchmueller
TODO:
- fix LCD digits display controlling
diff --git a/src/mame/drivers/mbee.cpp b/src/mame/drivers/mbee.cpp
index ce5bea06fd8..2768cce305a 100644
--- a/src/mame/drivers/mbee.cpp
+++ b/src/mame/drivers/mbee.cpp
@@ -77,7 +77,7 @@ from Brett Selwood and Andrew Davies.
- Most versions of Telcom can have their parameters adjusted directly from Basic,
without needing to enter the Telcom program.
- Most versions of Telcom have an optional clock. In older models firstly select VS
- from the MESS config menu, then enter NET CLOCK to enable it. NET TIME hhmm to set
+ from the MAME config menu, then enter NET CLOCK to enable it. NET TIME hhmm to set
the time (24hour format). NET CLOCKD is supposed to remove the status line, but it
doesn't, although the clock stops updating. NET CLOCK and NET CLOCKD are toggles.
- Telcom 1.2 (used in mbeeic) has a bug. If you enter NET CLOCK, the status line is
@@ -106,7 +106,7 @@ from Brett Selwood and Andrew Davies.
FDC: (TODO: see if these bugs still exist)
- B drive doesn't work with most disks.
- - some disks cause MESS to freeze.
+ - some disks cause MAME to freeze.
- 128k: Simply Write has no keyboard.
diff --git a/src/mame/drivers/megadriv.cpp b/src/mame/drivers/megadriv.cpp
index c922f1e5b78..fe81ca42560 100644
--- a/src/mame/drivers/megadriv.cpp
+++ b/src/mame/drivers/megadriv.cpp
@@ -652,7 +652,7 @@ void md_cons_state::genesis_32x(machine_config &config)
subdevice<screen_device>("megadriv")->screen_vblank().set(FUNC(md_cons_state::screen_vblank_console));
// we need to remove and re-add the YM because the balance is different
- // due to MAME / MESS having severe issues if the dac output is > 0.40? (sound is corrupted even if DAC is silent?!)
+ // due to MAME having severe issues if the dac output is > 0.40? (sound is corrupted even if DAC is silent?!)
m_ymsnd->reset_routes();
m_ymsnd->add_route(0, "lspeaker", (0.50)/2);
m_ymsnd->add_route(1, "rspeaker", (0.50)/2);
@@ -684,7 +684,7 @@ void md_cons_state::mdj_32x(machine_config &config)
subdevice<screen_device>("megadriv")->screen_vblank().set(FUNC(md_cons_state::screen_vblank_console));
// we need to remove and re-add the sound system because the balance is different
- // due to MAME / MESS having severe issues if the dac output is > 0.40? (sound is corrupted even if DAC is silent?!)
+ // due to MAME having severe issues if the dac output is > 0.40? (sound is corrupted even if DAC is silent?!)
m_ymsnd->reset_routes();
m_ymsnd->add_route(0, "lspeaker", (0.50)/2);
m_ymsnd->add_route(1, "rspeaker", (0.50)/2);
@@ -716,7 +716,7 @@ void md_cons_state::md_32x(machine_config &config)
subdevice<screen_device>("megadriv")->screen_vblank().set(FUNC(md_cons_state::screen_vblank_console));
// we need to remove and re-add the sound system because the balance is different
- // due to MAME / MESS having severe issues if the dac output is > 0.40? (sound is corrupted even if DAC is silent?!)
+ // due to MAME having severe issues if the dac output is > 0.40? (sound is corrupted even if DAC is silent?!)
m_ymsnd->reset_routes();
m_ymsnd->add_route(0, "lspeaker", (0.50)/2);
m_ymsnd->add_route(1, "rspeaker", (0.50)/2);
diff --git a/src/mame/drivers/mtouchxl.cpp b/src/mame/drivers/mtouchxl.cpp
index 96fbe2570a2..7a155c77c51 100644
--- a/src/mame/drivers/mtouchxl.cpp
+++ b/src/mame/drivers/mtouchxl.cpp
@@ -176,7 +176,7 @@ void mtxl_state::machine_start()
#ifndef REAL_PCI_CHIPSET
address_space& space = m_maincpu->space(AS_PROGRAM);
- /* MESS managed RAM */
+ /* managed RAM */
membank("bank10")->set_base(m_ram->pointer());
if (m_ram->size() > 0xa0000)
diff --git a/src/mame/drivers/mz2500.cpp b/src/mame/drivers/mz2500.cpp
index 83cbf72081c..e5f94a166af 100644
--- a/src/mame/drivers/mz2500.cpp
+++ b/src/mame/drivers/mz2500.cpp
@@ -24,7 +24,7 @@
- LayDock: hangs at title screen due of a PIT bug (timer irq dies for whatever reason);
- Moon Child: needs mixed 3+3bpp tvram supported, kludged for now (not a real test case);
- Moon Child: window masking doesn't mask bottom part of the screen?
- - Moon Child: appears to be a network / system link game, obviously doesn't work with current MAME / MESS framework;
+ - Moon Child: appears to be a network / system link game, obviously doesn't work with current MAME framework;
- Marchen Veil I: doesn't load if you try to run it directly, it does if you load another game first (for example Mappy) then do a soft reset;
- Mugen no Shinzou II - The Prince of Darkness: dies on IPLPRO loading, presumably a wd17xx core bug;
- Multiplan: random hangs/crashes after you set the RTC, sometimes it loads properly;
@@ -491,7 +491,7 @@ void mz2500_state::draw_cg_screen(bitmap_ind16 &bitmap,const rectangle &cliprect
draw_cg16_screen(bitmap,cliprect,2,640,pri);
break;
default:
- popmessage("Unsupported CG mode %02x, contact MESS dev",m_cg_reg[0x0e]);
+ popmessage("Unsupported CG mode %02x, contact MAME dev",m_cg_reg[0x0e]);
break;
}
}
diff --git a/src/mame/drivers/nc.cpp b/src/mame/drivers/nc.cpp
index 07e05c2969c..9dac8e3a4ce 100644
--- a/src/mame/drivers/nc.cpp
+++ b/src/mame/drivers/nc.cpp
@@ -2,8 +2,6 @@
// copyright-holders:Wilbert Pol, Kevin Thacker
/******************************************************************************
- nc.cpp
-
NC100/NC150/NC200 Notepad computer
system driver
@@ -83,16 +81,12 @@
Self Test:
- requires memory save and real time clock save to be working!
- (i.e. for MESS nc100 driver, nc100.nv can be created)
+ (i.e. for MAME nc100 driver, nc100.nv can be created)
- turn off nc (use NMI button)
- reset+FUNCTION+SYMBOL must be pressed together.
Note: NC200 Self test does not test disc hardware :(
-
-
- Kevin Thacker [MESS driver]
-
******************************************************************************/
#include "emu.h"
diff --git a/src/mame/drivers/pc8801.cpp b/src/mame/drivers/pc8801.cpp
index 592c0d50c91..86ebcdf1929 100644
--- a/src/mame/drivers/pc8801.cpp
+++ b/src/mame/drivers/pc8801.cpp
@@ -99,7 +99,7 @@
# Fangs - The Saga of Wolf Blood (Crashes at the first random battle)
- Fantasian
* Final Zone
- # Final Zone (demo) (REGRESSION: asserts at MESS boot)
+ # Final Zone (demo) (REGRESSION: asserts at MAME boot)
- Fruit Panic
- FSD Sample Ongaku Shuu Vol. 1-7
- Gaia no Kiba (Disk I/O error at 150)
diff --git a/src/mame/drivers/pencil2.cpp b/src/mame/drivers/pencil2.cpp
index c534360fa0f..cd96532617c 100644
--- a/src/mame/drivers/pencil2.cpp
+++ b/src/mame/drivers/pencil2.cpp
@@ -7,7 +7,7 @@
2012-11-06 [Robbbert]
- Computer kindly donated for MESS by Ian Farquhar.
+ Computer kindly donated for MAME by Ian Farquhar.
Accessories:
- PEN-216 : 16k RAM expansion
diff --git a/src/mame/drivers/photon2.cpp b/src/mame/drivers/photon2.cpp
index b550860e86a..a70b5517680 100644
--- a/src/mame/drivers/photon2.cpp
+++ b/src/mame/drivers/photon2.cpp
@@ -78,7 +78,7 @@ private:
/*************************************
*
- * Video (copied from MESS apart from support
+ * Video (copied from spectrum driver apart from support
* for changing border color mid-frame)
*
*************************************/
diff --git a/src/mame/drivers/ps2.cpp b/src/mame/drivers/ps2.cpp
index 70f4bb86060..fa5696aacb1 100644
--- a/src/mame/drivers/ps2.cpp
+++ b/src/mame/drivers/ps2.cpp
@@ -81,7 +81,7 @@ void ps2_state::machine_start()
{
address_space& space = m_maincpu->space(AS_PROGRAM);
- /* MESS managed RAM */
+ /* managed RAM */
membank("bank10")->set_base(m_ram->pointer());
if (m_ram->size() > 0xa0000)
diff --git a/src/mame/drivers/ql.cpp b/src/mame/drivers/ql.cpp
index 3febf58d924..1d37af7ff3a 100644
--- a/src/mame/drivers/ql.cpp
+++ b/src/mame/drivers/ql.cpp
@@ -4,8 +4,6 @@
Sinclair QL
- MESS Driver by Curt Coder
-
*/
/*
diff --git a/src/mame/drivers/spectrum.cpp b/src/mame/drivers/spectrum.cpp
index abe3781f182..7f945db26c1 100644
--- a/src/mame/drivers/spectrum.cpp
+++ b/src/mame/drivers/spectrum.cpp
@@ -601,7 +601,7 @@ in EXT+Shift Mode on a real Spectrum).
/* TO DO: replace PORT_CHAR(0xD7) with an 'empty' PORT_CHAR. I used \xD7 (multiplication sign) just as a placeholder. There should be no
PORT_CHAR for those functions (which have no equivalent on modern keyboards), but something is needed (to correctly have natural support for
-a few keys in SYMBOL Mode) and I found no EMPTY PORT_CHAR in MESS */
+a few keys in SYMBOL Mode) and I found no EMPTY PORT_CHAR in MAME */
INPUT_PORTS_START( spectrum )
/* PORT_NAME = KEY Mode CAPS Mode SYMBOL Mode EXT Mode EXT+Shift Mode BASIC Mode */
PORT_START("LINE0") /* 0xFEFE */
diff --git a/src/mame/drivers/swtpc09.cpp b/src/mame/drivers/swtpc09.cpp
index f616278d49a..0a48d6c8009 100644
--- a/src/mame/drivers/swtpc09.cpp
+++ b/src/mame/drivers/swtpc09.cpp
@@ -2,7 +2,7 @@
// copyright-holders:Robert Justice,68bit
/**************************************************************************
- SWTPC S/09 Mess driver
+ SWTPC S/09
Robert Justice ,2009-2014
Emulates four different fixed combinations of hardware
diff --git a/src/mame/drivers/thomson.cpp b/src/mame/drivers/thomson.cpp
index d823f1f073e..08031222c31 100644
--- a/src/mame/drivers/thomson.cpp
+++ b/src/mame/drivers/thomson.cpp
@@ -72,7 +72,7 @@
- digitisation extension (DI 90-011) (@)
- barcode reader (@)
- (@) means MESS is lacking support for this kind of device / feature anyway
+ (@) means MAME is lacking support for this kind of device / feature anyway
*/
@@ -250,9 +250,9 @@ boot floppy.
* devices:
- AZERTY keyboard, 58-keys, French with accents
- cartridge 16 KB (up to 64 KB using bank-switching),
- the MESS cartridge device is named -cart
+ the MAME cartridge device is named -cart
- cassette 900 bauds (frequency signals: 0=4.5 kHz, 1=6.3 kHz)
- the MESS cassette device is named -cass
+ the MAME cassette device is named -cass
- 1-bit internal buzzer
- lightpen, with 8-pixel horizontal resolution, 1-pixel vertical
- SX 90-018 game & music extension
@@ -280,7 +280,7 @@ boot floppy.
sides)
. floppies are 40 tracks/side, 16 sectors/track, 128 or 256 bytes/sector
= from 80 KB one-sided single-density, to 320 KB two-sided double-density
- . MESS floppy devices are named -flop0 to -flop3
+ . MAME floppy devices are named -flop0 to -flop3
- alternate 5"1/2 floppy drive extension
. CD 90-015 floppy controller, based on a HD 46503 S
. UD 90-070 5"1/4 single-sided single density floppy drive
diff --git a/src/mame/drivers/ti99_4p.cpp b/src/mame/drivers/ti99_4p.cpp
index 55e800c5ead..af2a49e020d 100644
--- a/src/mame/drivers/ti99_4p.cpp
+++ b/src/mame/drivers/ti99_4p.cpp
@@ -64,7 +64,7 @@
BLACK SCREEN.
In the real environment, the HSGPL has usually been set up on delivery.
- In MESS we have to create a suitable HSGPL memory content. Best practice
+ In MAME we have to create a suitable HSGPL memory content. Best practice
is to start the TI-99/4A console with EVPC support (driver ti99_4ev) with
a plugged-in HSGPL and to go through the setup process there.
Finally, the nvram files of the HSGPL must be copied into this driver's nvram
@@ -97,7 +97,7 @@
Video and sound
---------------
The SGCPU relies on the EVPC or EVPC2 card to provide video capabilities.
- This card (rel.1) is emulated in MESS and is based on the v9938 video
+ This card (rel.1) is emulated in MAME and is based on the v9938 video
display processor.
In order to route the VDP interrupt to the SGCPU card, the previously
unused LCP* line in the Peripheral Expansion Box is used.
diff --git a/src/mame/drivers/ti99_8.cpp b/src/mame/drivers/ti99_8.cpp
index af38d3507c9..94c03f282ef 100644
--- a/src/mame/drivers/ti99_8.cpp
+++ b/src/mame/drivers/ti99_8.cpp
@@ -2,7 +2,7 @@
// copyright-holders:Michael Zapf
/****************************************************************************
- The MESS TI-99/8 emulation driver
+ TI-99/8
The TI-99/8 was the envisaged successor to the TI-99/4A but never passed
its prototype state. Only a few dozen consoles were built. The ROMs
diff --git a/src/mame/drivers/v1050.cpp b/src/mame/drivers/v1050.cpp
index 3f559c2ca26..3a3864bc26c 100644
--- a/src/mame/drivers/v1050.cpp
+++ b/src/mame/drivers/v1050.cpp
@@ -105,8 +105,8 @@ Notes:
Start the Visual 1050 emulator with the floppy and hard disk images mounted:
- $ mess v1050 -flop1 cpm3:flop2 -hard tm501.chd
- $ mess v1050 -flop1 cpm3:flop2 -hard cm5412.chd
+ $ mame v1050 -flop1 cpm3:flop2 -hard tm501.chd
+ $ mame v1050 -flop1 cpm3:flop2 -hard cm5412.chd
Start the Winchester Format Program from the CP/M prompt:
@@ -128,13 +128,13 @@ Notes:
You can now boot from the hard disk with:
- $ mess v1050 -hard tm501.chd
- $ mess v1050 -hard cm5412.chd
+ $ mame v1050 -hard tm501.chd
+ $ mame v1050 -hard cm5412.chd
Or skip all of the above and use the preformatted images in the software list:
- $ mess v1050 -hard cpm3hd5
- $ mess v1050 -hard cpm3hd10
+ $ mame v1050 -hard cpm3hd5
+ $ mame v1050 -hard cpm3hd10
*/
diff --git a/src/mame/drivers/zx.cpp b/src/mame/drivers/zx.cpp
index f9db4e3c5c6..c7c18c2623d 100644
--- a/src/mame/drivers/zx.cpp
+++ b/src/mame/drivers/zx.cpp
@@ -94,7 +94,7 @@ void zx_state::pow3000_io_map(address_map &map)
static INPUT_PORTS_START( zx80 )
/* PORT_NAME = Key Mode (Press Key) Shift Mode (Press Key+Shift) BASIC Mode (Press Key at BASIC) */
-/* Some keys (e.g. A,S,D,F,G etc.) produce glyphs when used in Shift Mode. MESS currently cannot show
+/* Some keys (e.g. A,S,D,F,G etc.) produce glyphs when used in Shift Mode. MAME currently cannot show
these functions in Input (This System) menu, hence we live some empty space in the menu */
PORT_START("ROW0")
PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("SHIFT") PORT_CODE(KEYCODE_LSHIFT) PORT_CHAR(UCHAR_SHIFT_1)
diff --git a/src/mame/includes/n64.h b/src/mame/includes/n64.h
index cfbaa3fbbe5..16429b33995 100644
--- a/src/mame/includes/n64.h
+++ b/src/mame/includes/n64.h
@@ -143,7 +143,7 @@ public:
uint32_t vi_vburst;
uint8_t field;
- /* nvram-specific for MESS */
+ // nvram-specific for the console
device_t *m_nvram_image;
n64_savable_data_t m_save_data;
diff --git a/src/mame/machine/bbc.cpp b/src/mame/machine/bbc.cpp
index 4281e2b0f1c..3cd5f5f24c1 100644
--- a/src/mame/machine/bbc.cpp
+++ b/src/mame/machine/bbc.cpp
@@ -1,12 +1,8 @@
// license:BSD-3-Clause
// copyright-holders:Gordon Jefferyes, Nigel Barnes
/******************************************************************************
- BBC Model B
-
- MESS Driver By:
- Gordon Jefferyes
- mess_bbc@romvault.com
+ BBC Model B
******************************************************************************/
diff --git a/src/mame/machine/bebox.cpp b/src/mame/machine/bebox.cpp
index dbc7f198063..b08d6835014 100644
--- a/src/mame/machine/bebox.cpp
+++ b/src/mame/machine/bebox.cpp
@@ -768,7 +768,7 @@ void bebox_state::init_bebox()
/* set up boot and flash ROM */
membank("bank2")->set_base(memregion("user2")->base());
- /* install MESS managed RAM */
+ /* install managed RAM */
space_0.install_ram(0, m_ram->size() - 1, 0x02000000, m_ram->pointer());
space_1.install_ram(0, m_ram->size() - 1, 0x02000000, m_ram->pointer());
@@ -777,7 +777,7 @@ void bebox_state::init_bebox()
* lets CPU #1 go. However, it seems that CPU #1 jumps into never-never
* land, crashes, and then goes into NetBSD's crash handler which catches
* it. The current PowerPC core cannot catch this trip into never-never
- * land properly, and MESS crashes. In the interim, this "mitten" catches
+ * land properly, and MAME crashes. In the interim, this "mitten" catches
* the crash
*/
{
diff --git a/src/mame/machine/cdicdic.cpp b/src/mame/machine/cdicdic.cpp
index 4eb6cd44dac..f7d5d6bb1bc 100644
--- a/src/mame/machine/cdicdic.cpp
+++ b/src/mame/machine/cdicdic.cpp
@@ -1331,13 +1331,13 @@ void cdicdic_device::device_reset()
if (m_cdrom_dev)
{
- // MESS case (has CDROM device)
+ // Console case (has CDROM device)
m_cd = m_cdrom_dev->get_cdrom_file();
m_cdda->set_cdrom(m_cd);
}
else
{
- // MAME case
+ // Arcade case
m_cd = cdrom_open(machine().rom_load().get_disk_handle(":cdrom"));
m_cdda->set_cdrom(m_cd);
}
diff --git a/src/mame/machine/dccons.cpp b/src/mame/machine/dccons.cpp
index 08634ce1bd2..c5f40633271 100644
--- a/src/mame/machine/dccons.cpp
+++ b/src/mame/machine/dccons.cpp
@@ -4,7 +4,7 @@
dc.c - Sega Dreamcast hardware
- MESS (DC home console) hardware overrides (GD-ROM drive etc)
+ DC home console hardware overrides (GD-ROM drive etc)
c230048 - 5 is written, want 6
c0d9d9e - where bad happens, from routine @ c0da260
diff --git a/src/mame/machine/electron.cpp b/src/mame/machine/electron.cpp
index 464f4f7a0da..f27d8092ec6 100644
--- a/src/mame/machine/electron.cpp
+++ b/src/mame/machine/electron.cpp
@@ -1,11 +1,8 @@
// license:BSD-3-Clause
// copyright-holders:Wilbert Pol, Nigel Barnes
/******************************************************************************
- Acorn Electron driver
-
- MESS Driver By:
- Wilbert Pol
+ Acorn Electron driver
******************************************************************************/
diff --git a/src/mame/machine/n64.cpp b/src/mame/machine/n64.cpp
index 376a3b6162f..e29569aa1b0 100644
--- a/src/mame/machine/n64.cpp
+++ b/src/mame/machine/n64.cpp
@@ -1,6 +1,6 @@
// license:BSD-3-Clause
// copyright-holders:Ryan Holtz
-/* machine/n64.c - contains N64 hardware emulation shared between MAME and MESS */
+/* machine/n64.c - contains N64 hardware emulation shared between arcade and console */
#include "emu.h"
#include "debugger.h"
diff --git a/src/mame/machine/thomson.cpp b/src/mame/machine/thomson.cpp
index f8201ded8da..378bf038f1a 100644
--- a/src/mame/machine/thomson.cpp
+++ b/src/mame/machine/thomson.cpp
@@ -891,7 +891,7 @@ void thomson_state::to7_game_reset()
/* IMPORTANT NOTE:
The following is experimental and not compiled in by default.
It relies on the existence of an hypothetical "character device" API able
- to transmit bytes between the MESS driver and the outside world
+ to transmit bytes between the MAME driver and the outside world
(using, e.g., character device special files on some UNIX).
*/
diff --git a/src/mame/video/bbc.cpp b/src/mame/video/bbc.cpp
index f2d642c4d4e..ef59787cf69 100644
--- a/src/mame/video/bbc.cpp
+++ b/src/mame/video/bbc.cpp
@@ -1,12 +1,8 @@
// license:BSD-3-Clause
// copyright-holders:Gordon Jefferyes, Nigel Barnes
/******************************************************************************
- BBC Model B
-
- MESS Driver By:
- Gordon Jefferyes
- mess_bbc@romvault.com
+ BBC Model B
This is the first go around at converting the BBC code over to using
mames built in mc6845, there are a number of features now incorrect
diff --git a/src/mame/video/electron.cpp b/src/mame/video/electron.cpp
index 352e4710769..549ab4dc3ff 100644
--- a/src/mame/video/electron.cpp
+++ b/src/mame/video/electron.cpp
@@ -4,10 +4,6 @@
Acorn Electron driver
- MESS Driver By:
-
- Wilbert Pol
-
******************************************************************************/
#include "emu.h"
diff --git a/src/mame/video/nick.cpp b/src/mame/video/nick.cpp
index ddaf8c0aff2..4b119a4695d 100644
--- a/src/mame/video/nick.cpp
+++ b/src/mame/video/nick.cpp
@@ -354,7 +354,6 @@ void nick_device::initialize_palette()
}
}
-// MESS specific
/* 8-bit pixel write! */
void nick_device::write_pixel(int ci)
{
diff --git a/src/mame/video/tia.cpp b/src/mame/video/tia.cpp
index 36ee0175fbc..4ba53742b73 100644
--- a/src/mame/video/tia.cpp
+++ b/src/mame/video/tia.cpp
@@ -117,7 +117,7 @@ void tia_ntsc_video_device::init_palette()
values of red may appear too pinkish - Too much blue to red.
This is not the same as a traditional tint-hue control adjustment;
rather, can be demonstrated by changing the blue ratio values
- via MESS HLSL settings.
+ via MAME HLSL settings.
Lastly, the Atari 5200 & 7800 NTSC color palettes hold the same
hue structure order and have similar appearance differences that
diff --git a/src/mame/machine/amstrad.cpp b/src/mame/machine/amstrad.cpp
index 459e8cbea41..68b2dc8a408 100644
--- a/src/mame/machine/amstrad.cpp
+++ b/src/mame/machine/amstrad.cpp
@@ -2341,7 +2341,7 @@ void amstrad_state::amstrad_reset_machine()
/* set ram config 0 */
amstrad_GateArray_write(0x0c0);
// Get manufacturer name and TV refresh rate from PCB link (dipswitch for mess emulation)
m_ppi_port_inputs[amstrad_ppi_PortB] = (((m_io_solder_links->read()&MANUFACTURER_NAME)<<1) | (m_io_solder_links->read()&TV_REFRESH_RATE));
if ( m_system_type == SYSTEM_PLUS || m_system_type == SYSTEM_GX4000 )
@@ -2553,8 +2553,8 @@ Bit Description
7 Cassette read data
6 Parallel/Printer port ready signal ("1" = not ready, "0" = Ready)
5 /EXP signal on expansion port (note 6)
-4 50/60 Hz (link on PCB. For this MESS driver I have used the dipswitch feature) (note 5)
-3 | PCB links to define manufacturer name. For this MESS driver I have used the dipswitch feature. (note 1) (note 4)
+4 50/60 Hz (link on PCB. For this MAME driver I have used the dipswitch feature) (note 5)
+3 | PCB links to define manufacturer name. For this MAME driver I have used the dipswitch feature. (note 1) (note 4)
2 | (note 2)
1 | (note 3)
0 VSYNC State from 6845. "1" = VSYNC active, "0" = VSYNC inactive
@@ -2341,7 +2341,7 @@ void amstrad_state::amstrad_reset_machine()
/* set ram config 0 */
amstrad_GateArray_write(0x0c0);
- // Get manufacturer name and TV refresh rate from PCB link (dipswitch for mess emulation)
+ // Get manufacturer name and TV refresh rate from PCB link (dipswitch for MAME emulation)
m_ppi_port_inputs[amstrad_ppi_PortB] = (((m_io_solder_links->read()&MANUFACTURER_NAME)<<1) | (m_io_solder_links->read()&TV_REFRESH_RATE));
if ( m_system_type == SYSTEM_PLUS || m_system_type == SYSTEM_GX4000 )